@@ -2,7 +2,7 @@
 Cucumber result to Jira Xray Test repository
 
 """
-__version__ = "0.5.7"
+__version__ = "0.5.9"
 
 
 import datetime
@@ -13,6 +13,7 @@ import cujirax.xray.import_tests as test
 from cujirax.cucumber import Element
 from cujirax.jira import Jirakey, JiraX, Project
 from loguru import logger
+from collections import Counter
 
 
 class CuJiraX:
@@ -179,6 +180,13 @@ class CuJiraX:
             logger.info("search test case: " + test_name)
             logger.info(tests)
             found.append(el) if j.get_tests(test_name) else not_found.append(el)
+        
+        # check duplicate for new test
+        if not ignore_duplicate:
+            new_testnames = [cls.scenarioid_to_tescasename(el.id, el.keyword) for el in not_found]
+            duplicates = [item for item, count in Counter(new_testnames).items() if count > 1]
+            if duplicates:
+                raise ValueError("More than 1 same test detected: ", duplicates)
 
         return found, not_found
     
